@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
-# pylint: disable=wrong-import-position,import-error
+# pylint: disable=wrong-import-position,import-error,superfluous-parens
 ''' A menu listing domains '''
 import abc
 import asyncio
@@ -19,7 +19,7 @@ from qubesadmin import exc
 
 import gi  # isort:skip
 gi.require_version('Gtk', '3.0')  # isort:skip
-from gi.repository import Gio, Gtk, GObject, GLib  # isort:skip
+from gi.repository import Gio, Gtk, GObject, GLib, GdkPixbuf  # isort:skip
 
 import gbulb
 gbulb.install()
@@ -58,9 +58,15 @@ class IconCache:
         if icon_name in self.icons:
             icon = self.icons[icon_name]
         else:
-            icon = Gtk.IconTheme.get_default().load_icon(
-                self.icon_files[icon_name], 16, 0)
-            self.icons[icon_name] = icon
+            try:
+                icon = Gtk.IconTheme.get_default().load_icon(
+                    self.icon_files[icon_name], 16, 0)
+                self.icons[icon_name] = icon
+            except (TypeError, GLib.Error):
+                icon = GdkPixbuf.Pixbuf.new(GdkPixbuf.Colorspace.RGB,
+                                            True, 8, 16, 16)
+                icon.fill(0)
+                self.icons[icon_name] = icon
         return icon
 
 
@@ -271,6 +277,23 @@ class OpenFileManagerItem(Gtk.ImageMenuItem):
                            self.vm.name, str(ex)))
 
 
+class InternalInfoItem(Gtk.MenuItem):
+    ''' Restart menu Item. When activated shutdowns the domain and
+    then starts it again. '''
+
+    def __init__(self):
+        super().__init__()
+        self.label = Gtk.Label(xalign=0)
+        self.label.set_markup(_(
+                '<b>Internal qube</b>'))
+        self.set_tooltip_text(
+            'Internal qubes are used by the operating system. Do not modify'
+            ' them or run programs in them unless you really '
+            'know what you are doing.')
+        self.add(self.label)
+        self.set_sensitive(False)
+
+
 class StartedMenu(Gtk.Menu):
     ''' The sub-menu for a started domain'''
 
@@ -329,6 +352,39 @@ class DebugMenu(Gtk.Menu):
         self.show_all()
 
 
+class InternalMenu(Gtk.Menu):
+    """Sub-menu for Internal qubes"""
+    def __init__(self, vm, icon_cache, working_correctly=True):
+        """
+        :param vm: relevant Internal qube
+        :param icon_cache: IconCache object
+        :param working_correctly: if True, the VM should have a Shutdown
+        option; otherwise, have a Kill option
+        """
+        super().__init__()
+        self.vm = vm
+
+        self.add(InternalInfoItem())
+
+        logs = [
+            (_("Console Log"),
+             "/var/log/xen/console/guest-" + vm.name + ".log"),
+            (_("QEMU Console Log"),
+             "/var/log/xen/console/guest-" + vm.name + "-dm.log"),
+            ]
+
+        for name, path in logs:
+            if os.path.isfile(path):
+                self.add(LogItem(name, path))
+
+        if working_correctly:
+            self.add(ShutdownItem(self.vm, icon_cache))
+        else:
+            self.add(KillItem(self.vm, icon_cache))
+
+        self.show_all()
+
+
 def run_manager(_item):
     # pylint: disable=consider-using-with
     subprocess.Popen(['qubes-qube-manager'])
@@ -400,7 +456,10 @@ class DomainMenuItem(Gtk.ImageMenuItem):
         self.set_image(self.decorator.icon())
 
     def _set_submenu(self, state):
-        if state == 'Running':
+        if self.vm.features.get('internal', False):
+            submenu = InternalMenu(self.vm, self.icon_cache,
+                                   working_correctly=(state == 'Running'))
+        elif state == 'Running':
             submenu = StartedMenu(self.vm, self.app, self.icon_cache)
         elif state == 'Paused':
             submenu = PausedMenu(self.vm, self.icon_cache)
@@ -442,6 +501,7 @@ class DomainMenuItem(Gtk.ImageMenuItem):
         if state == 'Halted':
             self.hide()
             return
+        self.show_all()
 
         if state in ['Running', 'Paused']:
             self.hide_spinner()
@@ -470,8 +530,8 @@ class DomainTray(Gtk.Application):
         self.dispatcher = dispatcher
         self.stats_dispatcher = stats_dispatcher
 
-        self.widget_icon = Gtk.StatusIcon()
-        self.widget_icon.set_from_icon_name('qui-domains')
+        self.widget_icon: Gtk.StatusIcon = Gtk.StatusIcon()
+        self.widget_icon.set_from_icon_name('qui-domains-scalable')
         self.widget_icon.connect('button-press-event', self.show_menu)
         self.widget_icon.set_tooltip_markup(
             _('<b>Qubes Domains</b>\nView and manage running domains.'))
